fogus.java

Java host utilities.

Java host utilities.
raw docstring

array-dimclj

(array-dim mc)

Expects an array instance, or an array class mc and returns its dimensionality.

Expects an array instance, or an array class mc and returns its
dimensionality.
raw docstring

build-system-info-mapclj

(build-system-info-map)
(build-system-info-map base)

Returns a map containing mappings for various useful JVM sysprops. If a map base is provided then the sysprop mappings will be merged into it.

Returns a map containing mappings for various useful JVM sysprops.
If a map base is provided then the sysprop mappings will be merged
into it.
raw docstring

virtual-threads-available?clj

A boolean indicating if virtual threads are available at runtime.

A boolean indicating if virtual threads are available at runtime.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries