(gensym+)(gensym+ prefix)Works like clojure.core/gensym except adds metadata to the returned symbol with a :gensym->true mapping.
Works like clojure.core/gensym except adds metadata to the returned symbol with a :gensym->true mapping.
(lexeme? o)A predicate that checks if the argument is one of the lexical types: strings, keywords, or symbols.
A predicate that checks if the argument is one of the lexical types: strings, keywords, or symbols.
(qualified? id)Given an identifier id, returns true if it's namespace qualified, and false otherwise.
Given an identifier id, returns true if it's namespace qualified, and false otherwise.
(qualify s)(qualify q id)Qualify ident id by resolving it iff it's a symbol, using the given ns name, or using the current ns.
Qualify ident id by resolving it iff it's a symbol, using the given ns name, or using the current *ns*.
(unqualify lex)Remove the qualifying ns from the ident.
Remove the qualifying ns from the ident.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |