fogus.maps


assoc-iffclj

(assoc-iff m k v)
(assoc-iff m k v & kvs)

Like assoc, but only associates key-value pairs when the value is non-nil.

Like assoc, but only associates key-value pairs when the value is non-nil.
raw docstring

deep-mergeclj

(deep-merge & vals)

Recursively merges nested maps. When merging values at the same key:

  • If both values are maps, recursively merges them
  • Otherwise, takes the rightmost value (consistent with merge)
Recursively merges nested maps. When merging values at the same key:

- If both values are maps, recursively merges them
- Otherwise, takes the rightmost value (consistent with merge)
raw docstring

keys-applyclj

(keys-apply m ks f)

Takes a function, a set of keys, and a map and applies the function to the map on the given keys. A new map of the results of the function applied to the keyed entries is returned.

Takes a function, a set of keys, and a map and applies
the function to the map on the given keys.  A new map of
the results of the function applied to the keyed entries
is returned.
raw docstring

manip-keyscljdeprecated

(manip-keys m ks f)

DEPRECATED: use clojure.core/update-keys instead.

DEPRECATED: use clojure.core/update-keys instead.
raw docstring

manip-mapclj

(manip-map m ks f)

Takes a function, a set of keys, and a map and applies the function to the map on the given keys. A modified version of the original map is returned with the results of the function applied to each keyed entry.

Takes a function, a set of keys, and a map and applies the function
to the map on the given keys.  A modified version of the original map
is returned with the results of the function applied to each keyed entry.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries