Clojure only.

fogus.xf

Transducers

Transducers
raw docstring

slideclj

(slide n)

Returns a transducer that partitions the input stream into sliding windows each of size n. In case there are not enough elements to pad out the last window, then returns a partition with less than n items.

Returns a transducer that partitions the input stream into sliding
windows each of size n. In case there are not enough elements to pad
out the last window, then returns a partition with less than n items.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries