Java host utilities.
Java host utilities.
(array-dim mc)Expects an array instance, or an array class mc and returns its dimensionality.
Expects an array instance, or an array class mc and returns its dimensionality.
(build-system-info-map)(build-system-info-map base)Returns a map containing mappings for various useful JVM sysprops. If a map base is provided then the sysprop mappings will be merged into it.
Returns a map containing mappings for various useful JVM sysprops. If a map base is provided then the sysprop mappings will be merged into it.
A boolean indicating if virtual threads are available at runtime.
A boolean indicating if virtual threads are available at runtime.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |