(assoc-iff m k v)(assoc-iff m k v & kvs)Like assoc, but only associates key-value pairs when the value is non-nil.
Like assoc, but only associates key-value pairs when the value is non-nil.
(deep-merge & vals)Recursively merges nested maps. When merging values at the same key:
Recursively merges nested maps. When merging values at the same key: - If both values are maps, recursively merges them - Otherwise, takes the rightmost value (consistent with merge)
(keys-apply m ks f)Takes a function, a set of keys, and a map and applies the function to the map on the given keys. A new map of the results of the function applied to the keyed entries is returned.
Takes a function, a set of keys, and a map and applies the function to the map on the given keys. A new map of the results of the function applied to the keyed entries is returned.
(manip-keys m ks f)DEPRECATED: use clojure.core/update-keys instead.
DEPRECATED: use clojure.core/update-keys instead.
(manip-map m ks f)Takes a function, a set of keys, and a map and applies the function to the map on the given keys. A modified version of the original map is returned with the results of the function applied to each keyed entry.
Takes a function, a set of keys, and a map and applies the function to the map on the given keys. A modified version of the original map is returned with the results of the function applied to each keyed entry.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |