Transducers
Transducers
(slide n)Returns a transducer that partitions the input stream into sliding windows each of size n. In case there are not enough elements to pad out the last window, then returns a partition with less than n items.
Returns a transducer that partitions the input stream into sliding windows each of size n. In case there are not enough elements to pad out the last window, then returns a partition with less than n items.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |